import warnings
from django.conf import settings

autocert_settings_dict = getattr(settings, 'AUTOCERT', {})

LETSENCRYPT_PROD = 'https://acme-v01.api.letsencrypt.org/directory'
LETSENCRYPT_STAGING = 'https://acme-staging.api.letsencrypt.org/directory'
DIRECTORY_URL = autocert_settings_dict.get('DIRECTORY_URL', LETSENCRYPT_PROD)

# 2048 minimum for Let's Encrypt (Boulder)
BITS = autocert_settings_dict.get('BITS', 2048)

ACCOUNT_KEY_PASSWORD = autocert_settings_dict.get('ACCOUNT_KEY_PASSWORD', settings.SECRET_KEY)

OUTPUT_DIR = autocert_settings_dict.get('OUTPUT_DIR')

# Up to 100 per cert https://community.letsencrypt.org/t/rate-limits-for-lets-encrypt/6769
DEFAULT_SUBDOMAINS_TO_REQUEST = autocert_settings_dict.get('DEFAULT_SUBDOMAINS_TO_REQUEST', [])

for old_setting in ['SUBDOMAINS_TO_REQUEST', 'ENV_PREFIX']:
    if autocert_settings_dict.get(old_setting):
        msg = '{} setting deprecated, use DEFAULT_SUBDOMAINS_TO_REQUEST'.format(old_setting)
        warnings.warn(msg, DeprecationWarning)



import logging

from autocert.models import Certificate
from django.core.management.base import BaseCommand

log = logging.getLogger('command')


class Command(BaseCommand):
    help = 'Write all autocert Certificates to disk'

    def handle(self, *args, **options):
        for cert in Certificate.objects.all():
            cert.write_to_disk()



from django.contrib import admin, messages

from . import models


class AccountAdmin(admin.ModelAdmin):
    list_display = 'name directory_url'.split()
    fieldsets = (
        (None, {
            'fields': ('name',
                       ('is_registered', 'directory_url'))
        }),
        ('CSR Information', {
            'fields': (('country', 'state', 'locality'),
                       ('organization_name', 'organizational_unit_name'),
                       'email_address')
        }),

        ('Timestamps', {
            'fields': ('created', 'modified')
        }),
    )
    readonly_fields = ('is_registered', 'directory_url', 'created', 'modified')


class CertificateAdmin(admin.ModelAdmin):
    list_display = 'site certificate_common_name certificate_expiry_date'.split()
    fieldsets = (
        (None, {
            'fields': [('site', 'account'), 'domains_to_request']
        }),
        ('Artifacts', {
            'fields': ['csr', 'certificate', 'intermediate_certificates'],
            'classes': ['collapse']
        }),
        ('Timestamps', {
            'fields': ['certificate_expiry_date', 'created', 'modified']
        }),
    )
    readonly_fields = ('csr', 'certificate', 'intermediate_certificates', 'certificate_expiry_date',
                       'created', 'modified')
    actions = ['request_and_write_cert']

    def request_and_write_cert(self, request, queryset):
        for cert in queryset.all():
            try:
                cert.request_and_write_cert()
                self.message_user(request, message="Wrote certificate for {}".format(cert.domains_to_request))
            except Exception as e:
                self.message_user(request, message=e, level=messages.ERROR)
    request_and_write_cert.short_description = "Request and write certificate"


admin.site.register(models.Certificate, CertificateAdmin)
admin.site.register(models.Account, AccountAdmin)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-10-04 16:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('autocert', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='certificate',
            name='domains_to_request',
            field=models.TextField(blank=True, help_text='Space separated list of domains to request in cert'),
        ),
        migrations.RemoveField(
            model_name='certificate',
            name='domain',
        ),
    ]
